# Let Me Go

> letmego.

![PyPI](https://img.shields.io/pypi/v/letmego?style=flat&logo=github&link=https%3A%2F%2Fpypi.org%2Fproject%2Fletmego%2F)
![PyPI - License](https://img.shields.io/pypi/l/letmego)
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/letmego)
![PyPI - Wheel](https://img.shields.io/pypi/wheel/letmego)
![PyPI - Implementation](https://img.shields.io/pypi/implementation/letmego)

[![Downloads](https://static.pepy.tech/badge/letmego/week)](https://pepy.tech/project/letmego)
[![Downloads](https://static.pepy.tech/badge/letmego/month)](https://pepy.tech/project/letmego)
[![Downloads](https://static.pepy.tech/badge/letmego)](https://pepy.tech/project/letmego)

English | [简体中文](README.zh_CN.md) 

letmego is 

## Installation

- Installing from PyPI:

  ```shel
  sudo pip3 install letmego
  ```

## Usage

```sh
xx
```

## Documentations

- [Documents](https://mikigo.github.io/letmego/)

## Getting help

- [Official Forum](https://bbs.deepin.org/) for generic discussion and help.
- [Developer Center](https://github.com/linuxdeepin/developer-center) for BUG report and suggestions.
- [Wiki](https://wiki.deepin.org/)

## Getting involved

We encourage you to report issues and contribute changes

- [Contribution guide for developers](https://github.com/linuxdeepin/developer-center/wiki/Contribution-Guidelines-for-Developers-en) (English)
- [Translate for your language on Transifex](#) *please update to the actual Transifex link of this project*

## License

letmego is licensed under [Apache](LICENSE)